searchData={"items":[{"type":"module","title":"Mar","doc":"Using `Mar` makes the module a route.\nIt injects `Mar.Route` protocol and a struct.\nSet a `path` or the default is \"/\".\nAdd parameters in the path or in the `params` list.\n\n```elixir\ndefmodule MyApp do\n  use Mar, path: \"/post/:id\", params: [:likes, :comment]\nend\n```\n\nName your function after the HTTP method.\nTake HTTP parameters from a map.\nReturn a response body with text.\n\n```elixir\ndef get(%{id: id}) do\n  \"You are reading #{id}\"\nend\n```\n\nReturning a map will send a response in JSON.\n\n```elixir\ndef post(%{id: id, comment: comment}) do\n  %{\n    id: id,\n    comment: comment\n  }\nend\n```\n\nReturn a tuple to set HTTP status and headers.\n\n```elixir\ndef delete(%{id: _id}) do\n  # {status, header, body}\n  {301, [location: \"/\"], nil}\nend\n```\n\n`Mar.Route` protocol lets you access `Plug.Conn`.\n\n```elixir\ndefimpl Mar.Route do\n  # Mar.Route.MyApp\n\n  def before_action(route) do\n    # Access `route.conn` before the actions you have defined.\n    route\n  end\n\n  def after_action(route) do\n    # Access `route.conn` after the actions you have defined.\n    route\n  end\nend\n```","ref":"Mar.html"},{"type":"protocol","title":"Mar.Route","doc":"`Mar.Route` protocol lets you access `Plug.Conn`.\n\n```elixir\ndefmodule MyApp do\n  # ...\n\n  defimpl Mar.Route do\n    # Mar.Route.MyApp\n\n    def before_action(route) do\n      # Access `route.conn` before the actions you have defined.\n      route\n    end\n\n    def after_action(route) do\n      # Access `route.conn` after the actions you have defined.\n      route\n    end\n  end\nend\n\n```","ref":"Mar.Route.html"},{"type":"function","title":"Mar.Route.after_action/1","doc":"","ref":"Mar.Route.html#after_action/1"},{"type":"function","title":"Mar.Route.before_action/1","doc":"","ref":"Mar.Route.html#before_action/1"},{"type":"type","title":"Mar.Route.t/0","doc":"All the types that implement this protocol.","ref":"Mar.Route.html#t:t/0"},{"type":"extras","title":"Mar","doc":"# Mar\n\nSimple Web in Elixir","ref":"readme.html"},{"type":"extras","title":"Installation - Mar","doc":"Add Mar to your Mix file:\n\n```elixir\ndefmodule MyApp.Mix do\n  use Mix.Project\n  # ...\n  defp deps do\n    [\n      {:mar, \"~> 0.1.0\"}\n    ]\n  end\n  # ...\nend\n```\n\nAdd Mar as a child:\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n  # ...\n  def start(_type, _args) do\n    children = [\n      Mar\n    ]\n\n    options = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, options)\n  end\n  # ...\nend\n```\n\nAdd Mar to your page module:\n\n```elixir\ndefmodule MyApp.Page do\n  use Mar\n\n  def get(%{}) do\n    \"Hello, world!\"\n  end\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Use - Mar","doc":"Using `Mar` makes the module a route.\nIt injects `Mar.Route` protocol and a struct.\nSet a `path` or the default is \"/\".\nAdd parameters in the path or in the `params` list.\n\n```elixir\ndefmodule MyApp do\n  use Mar, path: \"/post/:id\", params: [:likes, :comment]\nend\n```\n\nName your function after the HTTP method.\nTake HTTP parameters from a map.\nReturn a response body with text.\n\n```elixir\ndef get(%{id: id}) do\n  \"You are reading #{id}\"\nend\n```\n\nReturning a map will send a response in JSON.\n\n```elixir\ndef post(%{id: id, comment: comment}) do\n  %{\n    id: id,\n    comment: comment\n  }\nend\n```\n\nReturn a tuple to set HTTP status and headers.\n\n```elixir\ndef delete(%{id: _id}) do\n  # {status, header, body}\n  {301, [location: \"/\"], nil}\nend\n```\n\n`Mar.Route` protocol lets you access `Plug.Conn`.\n\n```elixir\ndefimpl Mar.Route do\n  # Mar.Route.MyApp\n\n  def before_action(route) do\n    # Access `route.conn` before the actions you have defined.\n    route\n  end\n\n  def after_action(route) do\n    # Access `route.conn` after the actions you have defined.\n    route\n  end\nend\n```","ref":"readme.html#use"},{"type":"extras","title":"Reference - Mar","doc":"- [Mar on HexDocs](https://hexdocs.pm/mar)\n- [Proposal on Elixir Forum](https://elixirforum.com/t/62885)","ref":"readme.html#reference"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}